
# Workflow Guide

We need workflow were used when creating the initial packages and need to be updated to reflect the current workflows.

![Forcasting Workflow](Forcaster-v1.png){:class="img-responsive"}

![Optimizing Worflow](Optimizer-v1.png){:class="img-responsive"}

![Trading Workflow](Trader-v1.png){:class="img-responsive"}
